@@ -52,6 +52,7 @@ public class DorisSinkConnectorConfig {
     public static final long BUFFER_SIZE_BYTES_DEFAULT = 5000000;
     public static final long BUFFER_SIZE_BYTES_MIN = 1;
     public static final String TOPICS_TABLES_MAP = "doris.topic2table.map";
+    public static final String RECORD_TABLE_NAME_FIELD = "record.tablename.field";
     public static final String LABEL_PREFIX = "label.prefix";
 
     // Time in seconds
@@ -114,7 +115,6 @@ public class DorisSinkConnectorConfig {
         setFieldToDefaultValues(config, CONVERTER_MODE, CONVERT_MODE_DEFAULT);
         setFieldToDefaultValues(
                 config, DEBEZIUM_SCHEMA_EVOLUTION, DEBEZIUM_SCHEMA_EVOLUTION_DEFAULT);
-        setFieldToDefaultValues(config, ENABLE_2PC, String.valueOf(ENABLE_2PC_DEFAULT));
         setFieldToDefaultValues(config, JMX_OPT, String.valueOf(JMX_OPT_DEFAULT));
     }
 
@@ -243,6 +243,16 @@ public class DorisSinkConnectorConfig {
                         3,
                         ConfigDef.Width.NONE,
                         BUFFER_FLUSH_TIME_SEC)
+                .define(
+                        RECORD_TABLE_NAME_FIELD,
+                        Type.STRING,
+                        null,
+                        Importance.LOW,
+                        "The field name of record, and use this field value as the table name to be written",
+                        CONNECTOR_CONFIG,
+                        4,
+                        ConfigDef.Width.NONE,
+                        RECORD_TABLE_NAME_FIELD)
                 .define(
                         JMX_OPT,
                         ConfigDef.Type.BOOLEAN,
