@@ -20,22 +20,29 @@
 package org.apache.doris.kafka.connector.service;
 
 import com.codahale.metrics.MetricRegistry;
+import com.fasterxml.jackson.core.JsonProcessingException;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.google.common.annotations.VisibleForTesting;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.doris.kafka.connector.DorisSinkTask;
 import org.apache.doris.kafka.connector.cfg.DorisOptions;
 import org.apache.doris.kafka.connector.connection.ConnectionProvider;
 import org.apache.doris.kafka.connector.connection.JdbcConnectionProvider;
 import org.apache.doris.kafka.connector.metrics.DorisConnectMonitor;
 import org.apache.doris.kafka.connector.metrics.MetricsJmxReporter;
-import org.apache.doris.kafka.connector.utils.ConfigCheckUtils;
 import org.apache.doris.kafka.connector.writer.CopyIntoWriter;
 import org.apache.doris.kafka.connector.writer.DorisWriter;
 import org.apache.doris.kafka.connector.writer.StreamLoadWriter;
 import org.apache.doris.kafka.connector.writer.load.LoadModel;
 import org.apache.kafka.clients.consumer.OffsetAndMetadata;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.connect.data.Struct;
 import org.apache.kafka.connect.sink.SinkRecord;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -54,15 +61,15 @@ public class DorisDefaultSinkService implements DorisSinkService {
 
     private final ConnectionProvider conn;
     private final Map<String, DorisWriter> writer;
-    private final Map<String, String> topic2TableMap;
     private final DorisOptions dorisOptions;
     private final MetricsJmxReporter metricsJmxReporter;
     private final DorisConnectMonitor connectMonitor;
+    private final ObjectMapper objectMapper;
 
     DorisDefaultSinkService(Map<String, String> config) {
         this.dorisOptions = new DorisOptions(config);
+        this.objectMapper = new ObjectMapper();
         this.writer = new HashMap<>();
-        this.topic2TableMap = new HashMap<>();
         this.conn = new JdbcConnectionProvider(dorisOptions);
         MetricRegistry metricRegistry = new MetricRegistry();
         this.metricsJmxReporter = new MetricsJmxReporter(metricRegistry, dorisOptions.getName());
@@ -73,6 +80,11 @@ public class DorisDefaultSinkService implements DorisSinkService {
                         this.metricsJmxReporter);
     }
 
+    @Override
+    public void startTask(TopicPartition topicPartition) {
+        startTask(dorisOptions.getTopicMapTable(topicPartition.topic()), topicPartition);
+    }
+
     /**
      * Create new task
      *
@@ -81,9 +93,10 @@ public class DorisDefaultSinkService implements DorisSinkService {
      */
     @Override
     public void startTask(final String tableName, final TopicPartition topicPartition) {
-        // fetch topic partition
-        String nameIndex = getNameIndex(topicPartition.topic(), topicPartition.partition());
-        if (writer.containsKey(nameIndex)) {
+        // check if the task is already started
+        String writerKey =
+                getWriterKey(topicPartition.topic(), topicPartition.partition(), tableName);
+        if (writer.containsKey(writerKey)) {
             LOG.info("already start task");
         } else {
             String topic = topicPartition.topic();
@@ -92,10 +105,15 @@ public class DorisDefaultSinkService implements DorisSinkService {
             DorisWriter dorisWriter =
                     LoadModel.COPY_INTO.equals(loadModel)
                             ? new CopyIntoWriter(
-                                    topic, partition, dorisOptions, conn, connectMonitor)
+                                    tableName, topic, partition, dorisOptions, conn, connectMonitor)
                             : new StreamLoadWriter(
-                                    topic, partition, dorisOptions, conn, connectMonitor);
-            writer.put(nameIndex, dorisWriter);
+                                    tableName,
+                                    topic,
+                                    partition,
+                                    dorisOptions,
+                                    conn,
+                                    connectMonitor);
+            writer.put(writerKey, dorisWriter);
             metricsJmxReporter.start();
         }
     }
@@ -127,28 +145,33 @@ public class DorisDefaultSinkService implements DorisSinkService {
 
     @Override
     public void insert(SinkRecord record) {
-        String nameIndex = getNameIndex(record.topic(), record.kafkaPartition());
+        String tableName = getSinkDorisTableName(record);
+        String writerKey = getWriterKey(record.topic(), record.kafkaPartition(), tableName);
         // init a new topic partition
-        if (!writer.containsKey(nameIndex)) {
-            startTask(
-                    ConfigCheckUtils.tableName(record.topic(), this.topic2TableMap),
-                    new TopicPartition(record.topic(), record.kafkaPartition()));
+        if (!writer.containsKey(writerKey)) {
+            startTask(tableName, new TopicPartition(record.topic(), record.kafkaPartition()));
         }
-        writer.get(nameIndex).insert(record);
+        writer.get(writerKey).insert(record);
     }
 
     @Override
     public long getOffset(final TopicPartition topicPartition) {
-        String name = getNameIndex(topicPartition.topic(), topicPartition.partition());
-        if (writer.containsKey(name)) {
-            return writer.get(name).getOffset();
-        } else {
+        String tpName = getNameIndex(topicPartition.topic(), topicPartition.partition());
+        // get all writers for the topic partition
+        List<DorisWriter> writers =
+                writer.entrySet().stream()
+                        .filter(entry -> entry.getKey().startsWith(tpName))
+                        .map(Map.Entry::getValue)
+                        .collect(Collectors.toList());
+        if (writers.isEmpty()) {
             LOG.info(
                     "Topic: {} Partition: {} hasn't been initialized to get offset",
                     topicPartition.topic(),
                     topicPartition.partition());
             return 0;
         }
+        // return the max offset of all writers
+        return writers.stream().map(DorisWriter::getOffset).reduce(Long::max).orElse(0L);
     }
 
     @Override
@@ -161,12 +184,78 @@ public class DorisDefaultSinkService implements DorisSinkService {
         offsets.keySet()
                 .forEach(
                         tp -> {
-                            String name = getNameIndex(tp.topic(), tp.partition());
-                            writer.get(name).commit(tp.partition());
+                            String tpName = getNameIndex(tp.topic(), tp.partition());
+                            // commit all writers that match the topic and partition
+                            for (Map.Entry<String, DorisWriter> entry : writer.entrySet()) {
+                                if (entry.getKey().startsWith(tpName)) {
+                                    entry.getValue().commit(tp.partition());
+                                }
+                            }
                         });
     }
 
+    /**
+     * Get the table name in doris for the given record.
+     *
+     * @param record sink record
+     * @return table name in doris
+     */
+    @VisibleForTesting
+    public String getSinkDorisTableName(SinkRecord record) {
+        String defaultTableName = dorisOptions.getTopicMapTable(record.topic());
+        String field = dorisOptions.getTableNameField();
+        // if the field is not set, use the table name in the config
+        if (StringUtils.isEmpty(field)) {
+            return defaultTableName;
+        }
+        return parseRecordTableName(defaultTableName, field, record);
+    }
+
+    private String parseRecordTableName(
+            String defaultTableName, String tableNameField, SinkRecord record) {
+        Object recordValue = record.value();
+        Map<String, Object> recordMap = Collections.emptyMap();
+        if (recordValue instanceof Struct) {
+            LOG.warn(
+                    "The Struct type record not supported for The 'record.tablename.field' configuration, field={}",
+                    tableNameField);
+            return defaultTableName;
+        } else if (recordValue instanceof Map) {
+            recordMap = (Map<String, Object>) recordValue;
+        } else if (recordValue instanceof String) {
+            try {
+                recordMap = objectMapper.readValue((String) recordValue, Map.class);
+            } catch (JsonProcessingException e) {
+                LOG.warn(
+                        "The String type record failed to parse record value to map. record={}, field={}",
+                        recordValue,
+                        tableNameField,
+                        e);
+            }
+        }
+        // if the field is not found in the record, use the table name in the config
+        if (!recordMap.containsKey(tableNameField)) {
+            return defaultTableName;
+        }
+        return recordMap.get(tableNameField).toString();
+    }
+
     private static String getNameIndex(String topic, int partition) {
         return topic + "_" + partition;
     }
+
+    /**
+     * Parse the writer unique key
+     *
+     * @param topic topic name
+     * @param partition partition number
+     * @param tableName table name
+     * @return writer key
+     */
+    private String getWriterKey(String topic, int partition, String tableName) {
+        if (dorisOptions.getTopicMapTable(topic).equals(tableName)) {
+            return topic + "_" + partition;
+        }
+        return topic + "_" + partition + "_" + tableName;
+    }
 }
