@@ -45,15 +45,16 @@ public class CopyIntoWriter extends DorisWriter {
     private final String prefix;
 
     public CopyIntoWriter(
+            String tableName,
             String topic,
             int partition,
             DorisOptions dorisOptions,
             ConnectionProvider connectionProvider,
             DorisConnectMonitor connectMonitor) {
-        super(topic, partition, dorisOptions, connectionProvider, connectMonitor);
+        super(tableName, topic, partition, dorisOptions, connectionProvider, connectMonitor);
         this.taskId = dorisOptions.getTaskId();
         this.prefix = FileNameUtils.filePrefix(dorisOptions.getName(), topic, partition);
-        this.copyLoad = new CopyLoad(dbName, tableName, dorisOptions);
+        this.copyLoad = new CopyLoad(dbName, this.tableName, dorisOptions);
     }
 
     public void fetchOffset() {
@@ -82,17 +83,14 @@ public class CopyIntoWriter extends DorisWriter {
         String offsetQuery = String.format(SQL_TEMPLATE, dbName, tableName, filePrefix);
         LOG.info("query offset by sql: {}", offsetQuery);
         List<String> loadFileList = new ArrayList<>();
-        try {
-            Connection connection = connectionProvider.getOrEstablishConnection();
-            PreparedStatement ps = connection.prepareStatement(offsetQuery);
-            ResultSet rs = ps.executeQuery();
+        try (Connection connection = connectionProvider.getOrEstablishConnection();
+                PreparedStatement ps = connection.prepareStatement(offsetQuery);
+                ResultSet rs = ps.executeQuery()) {
             while (rs.next()) {
                 String filesStr = rs.getString("Files");
                 String[] files = objectMapper.readValue(filesStr, String[].class);
                 loadFileList.addAll(Arrays.asList(files));
             }
-            rs.close();
-            ps.close();
         } catch (Exception ex) {
             LOG.warn(
                     "Failed to get copy-into file name, causing the doris kafka connector to not guarantee exactly once.",
