@@ -23,6 +23,4 @@ package org.apache.doris.kafka.connector.writer;
 public class LoadStatus {
     public static final String SUCCESS = "Success";
     public static final String PUBLISH_TIMEOUT = "Publish Timeout";
-    public static final String LABEL_ALREADY_EXIST = "Label Already Exists";
-    public static final String FAIL = "Fail";
 }
